@@ -22,17 +22,11 @@ our @EXPORT = qw(
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 # Load the Perl modules.
 use POSIX qw(ttyname);
 
-# Define the directory for Inline. 
-use Inline Config => DIRECTORY => '/tmp/';
-
-# Use inline C code.
-use Inline 'C';
-
 # Set the global output format.
 our $OutputFormat = ""; 
 
@@ -42,11 +36,18 @@ our $FN_SHELLS;
 
 # Define the Perl BEGIN block.
 BEGIN {
+    # Check the operating system.
+    if ($^O eq "MSWin32") {
+        # Print message to terminal window.
+        print "This module works not on Windows. Bye.\n";
+        # Exit script with error code 1.
+        exit 1;
+    };
     # Set some variables.
     $FN_PASSWD = "/etc/passwd";
     $FN_SHELLS = "/etc/shells";
     # Check if Linux command which exists.
-    if (! -x "/bin/which" || ! -x "/usr/bin/which") {
+    if (! -x "/bin/which" && ! -x "/usr/bin/which") {
         die "Linux command 'which' does not exist.\n";
     };
     # Check if grep, users and ps exists.
@@ -67,6 +68,12 @@ BEGIN {
     *identify_terminal = \&whichterminalami;
 };
 
+# Define the directory for Inline. 
+use Inline Config => DIRECTORY => '/tmp/';
+
+# Use inline C code.
+use Inline 'C';
+
 # Assign terminal process name to known terminal name.
 our %termhash = (
     # Successful tested.
@@ -120,6 +127,7 @@ our %termhash = (
     "foot"                   => "foot",                  
     "havoc"                  => "Havoc",                 
     "pantheon-terminal"      => "Pantheon Terminal",       
+    "putty"                  => "PuTTY",
     "rxvt-unicode-truecolor" => "rxvt-unicode-truecolor",
     "terminal"               => "Terminal",               
     "terminix"               => "Terminix",             
@@ -334,22 +342,29 @@ sub term_user_shell {
     my $passwd_content = $_[0];
     my @user_array = @{$_[1]};
     my @shell_array = @{$_[2]};
+    # Initialise variable $term.
+    my $term = "";
     # Get the username related to the terminal.
     my $username = get_username();
     # Declare the return array.
     my @result_array = ();
     # Get the terminal path.
     my $term_path = get_termpath();
-    # If $term_path is not defined leave the subroutine.
-    if (!defined $term_path) {
-        # Return an empty array. 
-        return ();
-    };
-    # Extract the pseudo terminal slave. 
-    my ($term) = $term_path =~ /^.*\/dev\/(pts\/\d+)$/;
-    # If $term is not defined check if it is a ? or a tty.
-    if (!defined $term) {
-        ($term) = $term_path =~ /^.*\/dev\/(tty\d+)$/;
+    # If $term_path is not defined or empty set $term to ?.
+    if (!defined $term_path || $term_path eq "") {
+        # Set variable $term_path.
+        $term = "?";
+    } else {
+        # Check on pts and tty.
+        if ($term_path =~ /^.*\/dev\/(pts\/\d+)$/) {
+            # Extract the pseudo terminal slave. 
+            ($term) = $term_path =~ /^.*\/dev\/(pts\/\d+)$/;
+        } elsif ($term_path =~ /^.*\/dev\/(tty\d+)$/) {
+            # Extract the terminal TeleTYpewriter. 
+            ($term) = $term_path =~ /^.*\/dev\/(tty\d+)$/;
+        } else {
+            $term = "?";
+        };
     };
     # Loop over the array with the lines of $passwd_content.
     foreach (split '\n', $passwd_content) {
@@ -473,6 +488,10 @@ sub terminal_identifier {
     my $content = read_file($filename);
     # Create the array with user and shell.
     my @result = term_user_shell($content, \@user_arr, \@shell_arr);
+    # check if @result is empty.
+    if (@result == 0) {
+        return "";
+    };
     # Create the array with user and term.
     my @match = terminal_process(\@result);
     # Check if array is empty.
@@ -586,17 +605,6 @@ sub get_terminal_ftn {
     return $terminal_ftn; 
 };
 
-# ============================================================================ #
-# Subroutine check_os                                                          # 
-# ============================================================================ #
-sub check_os{ 
-    # Check the operating system.
-    if ($^O eq "MSWin32") {
-        print "This module works not on Windows. Bye.\n";
-        exit 1;
-    };
-};
-
 # ============================================================================ #
 # Subroutine whichterminalami                                                  # 
 #                                                                              #
@@ -607,8 +615,6 @@ sub check_os{
 # @return:   $terminal       Terminal name       (scalar)                      #
 # ============================================================================ #
 sub whichterminalami {
-    # Check the operating system.
-    check_os();
     # Initialise the output format flag variable.
     my $flag = "";
     # Set the output format flag.
